@@ -69,13 +69,13 @@ bool SearchJob::startRemote(const QString &urlString)
     mKioJob = job;
     return true;
 }
- 
+
 SearchJob::~SearchJob()
 {
     delete mProcess;
     delete mKioJob;
 }
-    
+
 void SearchJob::searchExited( int exitCode, QProcess::ExitStatus exitStatus )
 {
     if ( exitStatus == QProcess::NormalExit && exitCode == 0 ) {
@@ -145,6 +145,10 @@ ExternalProcessSearchHandler::ExternalProcessSearchHandler( const KConfigGroup &
   mSearchCommand = cg.readEntry( "SearchCommand" );
   mSearchUrl = cg.readEntry( "SearchUrl" );
   mIndexCommand = cg.readEntry( "IndexCommand" );
+  mTryExec = cg.readEntry( "TryExec" );
+  mSearchBinary = cg.readEntry( "SearchBinary" );
+  const QStringList searchBinaryPaths = cg.readEntry( "SearchBinaryPaths", QStringList() );
+  mSearchBinary = KStandardDirs::findExe(mSearchBinary, searchBinaryPaths.join(":"));
 }
 
 QString ExternalProcessSearchHandler::indexCommand( const QString &identifier )
@@ -156,13 +160,22 @@ QString ExternalProcessSearchHandler::indexCommand( const QString &identifier )
   return cmd;
 }
 
-bool ExternalProcessSearchHandler::checkPaths() const
+bool ExternalProcessSearchHandler::checkPaths(QString* error) const
 {
-  if ( !mSearchCommand.isEmpty() && !checkBinary( mSearchCommand ) )
+  if ( !mSearchCommand.isEmpty() && !checkBinary( mSearchCommand ) ) {
+    *error = i18n("'%1' not found, check your installation", mSearchCommand);
     return false;
+  }
 
-  if ( !mIndexCommand.isEmpty() && !checkBinary( mIndexCommand ) )
+  if ( !mIndexCommand.isEmpty() && !checkBinary( mIndexCommand ) ) {
+    *error = i18n("'%1' not found, check your installation", mIndexCommand);
     return false;
+  }
+
+  if ( !mTryExec.isEmpty() && !checkBinary( mTryExec ) ) {
+    *error = i18n("'%1' not found, install the package containing it", mTryExec);
+    return false;
+  }
 
   return true;
 }
@@ -186,7 +199,7 @@ void ExternalProcessSearchHandler::search( DocEntry *entry, const QStringList &w
 
   if ( !mSearchCommand.isEmpty() ) {
     QString cmdString = SearchEngine::substituteSearchQuery( mSearchCommand,
-      entry->identifier(), words, maxResults, operation, mLang );
+      entry->identifier(), words, maxResults, operation, mLang, mSearchBinary );
 
     kDebug() << "CMD:" << cmdString;
 
@@ -199,7 +212,7 @@ void ExternalProcessSearchHandler::search( DocEntry *entry, const QStringList &w
 
   } else if ( !mSearchUrl.isEmpty() ) {
     QString urlString = SearchEngine::substituteSearchQuery( mSearchUrl,
-      entry->identifier(), words, maxResults, operation, mLang );
+      entry->identifier(), words, maxResults, operation, mLang, mSearchBinary );
 
     kDebug() << "URL:" << urlString;
 
