@@ -139,7 +139,8 @@ int sftpProtocol::auth_callback(const char *prompt, char *buf, size_t len,
   info.username = i_prompt;
   info.readOnly = true;
   info.prompt = i_prompt;
-  info.keepPassword = false;
+  info.keepPassword = false; // don't save passwords for public key,
+                             // that's the task of ssh-agent.
 
   if (!openPasswordDialog(info)) {
     kDebug(KIO_SFTP_DB) << "Password dialog failed";
@@ -226,7 +227,6 @@ int sftpProtocol::authenticateKeyboardInteractive(AuthInfo &info) {
         } else {
           info.readOnly = true; // set username readonly
           info.prompt = prompt;
-          info.keepPassword = false;
 
           if (openPasswordDialog(info)) {
             kDebug(KIO_SFTP_DB) << "Got the answer from the password dialog";
@@ -479,7 +479,7 @@ void sftpProtocol::openConnection() {
   info.comment = "sftp://" + mHost + ':' + QString::number(mPort);
   info.commentLabel = i18n("site:");
   info.username = mUsername;
-  info.keepPassword = true;
+  info.keepPassword = true; // make the "keep Password" check box visible to the user.
 
   // Check for cached authentication info if no password is specified...
   if (mPassword.isEmpty()) {
@@ -1068,6 +1068,8 @@ void sftpProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags) {
   const QByteArray dest_orig_c = dest_orig.toUtf8();
   const QString dest_part = dest_orig + ".part";
   const QByteArray dest_part_c = dest_part.toUtf8();
+  uid_t owner = 0;
+  gid_t group = 0;
 
   sftp_attributes sb = sftp_lstat(mSftp, dest_orig_c.constData());
   const bool bOrigExists = (sb != NULL);
@@ -1077,6 +1079,8 @@ void sftpProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags) {
   // Don't change permissions of the original file
   if (bOrigExists) {
       permissions = sb->permissions;
+      owner = sb->uid;
+      group = sb->gid;
   }
 
   if (bMarkPartial) {
@@ -1245,6 +1249,14 @@ void sftpProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags) {
     }
   }
 
+  // set original owner and group
+  if (bOrigExists) {
+      kDebug(KIO_SFTP_DB) << "Trying to restore original owner and group of " << dest_orig;
+      if (sftp_chown(mSftp, dest_orig_c.constData(), owner, group) < 0) {
+          // warning(i18n( "Could not change owner and group for\n%1", dest_orig));
+      }
+  }
+
   // set modification time
   const QString mtimeStr = metaData("modified");
   if (!mtimeStr.isEmpty()) {
