@@ -53,6 +53,13 @@ namespace Oxygen
         virtual ~DataMap( void )
         {}
 
+        //! insertion
+        virtual typename QMap< Key, Value >::iterator insert( const Key& key, const Value& value, bool enabled = true )
+        {
+            if( value ) value.data()->setEnabled( enabled );
+            return QMap< Key, Value >::insert( key, value );
+        }
+
         //! find value
         Value find( Key key )
         {
@@ -79,12 +86,7 @@ namespace Oxygen
             if( key == lastKey_ )
             {
 
-                if( lastValue_ )
-                {
-                    lastValue_.data()->deleteLater();
-                    lastValue_.clear();
-                }
-
+                if( lastValue_ ) lastValue_.clear();
                 lastKey_ = NULL;
 
             }
@@ -94,7 +96,7 @@ namespace Oxygen
             if( iter == QMap<Key, Value>::end() ) return;
 
             // delete value from map if found
-            if( iter.value() ) iter.value().data()->deleteLater();
+            if( iter.value() ) delete iter.value().data();
             QMap<Key, Value>::erase( iter );
 
             return;
